@@ -1,8 +1,3 @@
-from email import header
-from pydoc import cli
-from tkinter import NS
-from typing import AsyncContextManager
-from typing_extensions import final
 from async_timeout import asyncio
 from diskcache import Cache
 from threading import Lock
@@ -263,7 +258,11 @@ class Client(Singleton):
         return ret, e
     
     def get(self, path, url, force_copy=False, min_size=0, timeout=60, refresh=False):
-        bucket, bucket_name = url.split('/')
+        if '://' in url:
+            bucket, bucket_name = url.split('://')[1].split('/')
+        else:
+            bucket, bucket_name = url.split('/')
+
         task_id = 'tmp_file_{}_{}'.format(bucket, bucket_name)
         if not refresh:
             if '://' in url:
@@ -304,7 +303,11 @@ class Client(Singleton):
         return False, '获取失败'
 
     async def get_async(self, path, url, force_copy=False, min_size=0, timeout=60, refresh=False):
-        bucket, bucket_name = url.split('/')
+        if '://' in url:
+            bucket, bucket_name = url.split('://')[1].split('/')
+        else:
+            bucket, bucket_name = url.split('/')
+            
         task_id = 'tmp_file_{}_{}'.format(bucket, bucket_name)
         if not refresh:
             if '://' in url:
